@@ -2,7 +2,7 @@ import argparse
 from pathlib import Path
 
 from genki_wave.callbacks import ButtonAndDataPrint, CsvOutput
-from genki_wave.asyncio import run_asyncio_bluetooth, run_asyncio_serial
+from genki_wave.asyncio_runner import run_asyncio_bluetooth, run_asyncio_serial
 from genki_wave.discover import run_discover_bluetooth
 
 
